@@ -168,8 +168,11 @@ def create_project(project_name):
     create_project_gitignore()
     create_server_config_json()
     copy_deploy_files(directories['main'])
-    create_dvc_init_file()
+    # create_dvc_init_file()
+    # create_git_init_file()
+    change_to_project_dir()
     run_dvc_init()
+    run_git_init()
     #
     # create_tester_file(project_name, 'dataset')
     # create_tester_file(project_name, 'reporter')
@@ -404,23 +407,21 @@ def create_server_config_json():
             f.write(data)
             f.close()
 
-def create_dvc_init_file():
-    with open(os.path.join(__location__, 'cli/tester/deploy_files/dvc_init.sh'), 'r') as file:
-        data = file.read()
-        data = data.replace('generatedDirectory', directories['main'])
-        new_file = directories['main'] + '/dvc_init.sh'
-        if not os.path.exists(new_file):
-            f = open(new_file, "w")
-            f.write(data)
-            f.close()
+def change_to_project_dir():
+    os.chdir(directories['main'])
 
 def run_dvc_init():
-    if not os.path.isdir(directories['main'] + '/.dvc'):
-        os.chdir(directories['main'])
+    if not os.path.isdir('/.dvc'):
         command = 'dvc_init.sh'
         if not isWindows:
             command = './' + command
-            os.chmod(command, 444)
+        subprocess.call(command, shell=True)
+
+def run_git_init():
+    if not os.path.isdir('/.git'):
+        command = 'git_init.sh'
+        if not isWindows:
+            command = './' + command
         subprocess.call(command, shell=True)
 
 def copy_deploy_files(main_dir):
@@ -447,6 +448,9 @@ def copy_deploy_files(main_dir):
                         f = open(dirToCreate + file_path, "w")
                         f.write(data)
                         f.close()
+                        # Make sure that .sh files can be executed
+                        if (dirToCreate + file_path).endswith('.sh'):
+                            os.chmod(dirToCreate + file_path, 0o744)
                 except Exception as ex:
                     pass
     # for item in os.listdir(dir):
